<?php
/**
 * @package     KL Admin Skin
 * @subpackage  Quickicon
 *
 * @author      KreativeLizard Team <support@kreativelizard.com>
 * @copyright   Copyright (C) 2014 - 2020 KreativeLizard. All rights reserved.
 * @license     GNU General Public License version 3 or later; see LICENSE.txt
 * @link        https://www.kreativelizard.com
 */

// No direct access
defined('_JEXEC') or die;

/**
 * Kl Admin Skin Quick Icon plugin

 * @since  3.0.4
 */
class PlgQuickiconKl_adminskin extends JPlugin
{
	/**
	 * Load the language file on instantiation
	 *
	 * @var    boolean
	 * @since  3.6.1
	 */
	protected $autoloadLanguage = true;

	/**
	 * This method is called when the Quick Icons module is constructing its set
	 * of icons. You can return an array which defines a single icon and it will
	 * be rendered right after the stock Quick Icons.
	 *
	 * @param   string  $context  The calling context
	 *
	 * @return  null|array  A list of icon definition associative arrays, consisting of the
	 *				   keys link, image, text and access.
	 *
	 * @since   3.0.4
	 */
	public function onGetIcons($context)
	{
		if ($context !== $this->params->get('context', 'mod_quickicon')
			|| !JFactory::getUser()->authorise('core.manage', 'com_installer'))
		{
			return null;
		}

		// Main plugin definition
		$folder = 'system';
		$name   = 'kl_adminskin';

        // Run only if the master plugin is enabled
		if (!JPluginHelper::isEnabled($folder, $name))
		{
			return null;
		}

		// Register dependent class
		JLoader::register('AdminSkinHelper', JPATH_PLUGINS . '/system/kl_adminskin/helpers/helper.php');

		// Get main plugin id
		$id = AdminSkinHelper::getPluginId($folder, $name);

		// Set label value
		$label = $this->params->get('quickiconlabel', '');

		if (!$label)
		{
			$label = JText::_('PLG_QUICKICON_KL_ADMINSKIN_QUICKICON');
		}
		
		// Set group value
		$group = strtoupper($this->params->get('quickicongroup', 'configuration'));
		
		return array(
			array(
				'link'   => JRoute::_('index.php?option=com_plugins&task=plugin.edit&extension_id=' . $id),
				'image'  => 'brush',
				'text'   => $label,
				'id'     => 'plg_quickicon_kl_adminskin',
				'group'  => 'MOD_QUICKICON_' . $group
			)
		);
	}
}
